Struct rmp_futures::decode::ArrayFuture
source · [−]pub struct ArrayFuture<R> { /* private fields */ }Implementations
sourceimpl<R: AsyncRead + Unpin> ArrayFuture<R>
impl<R: AsyncRead + Unpin> ArrayFuture<R>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn next(self) -> MsgPackOption<MsgPackFuture<Self>, R>
pub fn next_dyn(
&mut self
) -> Option<MsgPackFuture<&mut (dyn AsyncRead + Unpin + Send)>>where
R: Send,
sourcepub fn last(self) -> MsgPackOption<MsgPackFuture<R>, R>
pub fn last(self) -> MsgPackOption<MsgPackFuture<R>, R>
If this is the last element, return a future of it’s value wrapped around the
underlying reader. Avoids having to call next() a final time.
sourcepub async fn skip(self) -> IoResult<R>where
R: Send,
pub async fn skip(self) -> IoResult<R>where
R: Send,
Consume all remaining elements and return the underlying reader
pub async fn into_value_vec(self) -> IoResult<(Vec<Value>, R)>where
R: Send,
pub fn into_value(self) -> impl Future<Output = IoResult<(Value, R)>>where
R: Send,