Struct rmp_futures::encode::MapFuture
source · [−]pub struct MapFuture<W> { /* private fields */ }Implementations
sourceimpl<W: AsyncWrite + Unpin> MapFuture<W>
impl<W: AsyncWrite + Unpin> MapFuture<W>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
sourcepub fn end(self) -> W
pub fn end(self) -> W
Return the underlying writer from this MapFuture that has already
written all elements (len == 0).
#Panics
Panics if self.is_empty() is false. next() must have been called as
many times as the map length originally written before calling this to
destroy the array wrapper.
pub fn next_key(self) -> MsgPackOption<MsgPackWriter<MsgPackWriter<Self>>, W>
pub fn next_key_dyn(
&mut self
) -> Option<MsgPackWriter<MsgPackWriter<&mut (dyn AsyncWrite + Send + Unpin)>>>where
W: Send,
sourcepub fn last_key(self) -> MsgPackOption<MsgPackWriter<MsgPackWriter<W>>, W>
pub fn last_key(self) -> MsgPackOption<MsgPackWriter<MsgPackWriter<W>>, W>
If this is the last element, return a future of it’s value wrapped around the
underlying writer. Avoids having to call next() a final time.
pub async fn write_value(self, a: &[(Value, Value)]) -> IoResult<W>where
W: Send,
pub async fn write_value_ref<'a>(
self,
a: &[(ValueRef<'a>, ValueRef<'a>)]
) -> IoResult<W>where
W: Send,