pub struct MsgPackWriter<W> { /* private fields */ }

Implementations

Write any int (u8-u64,i8-i64) in the most efficient representation

Encodes and attempts to write the most efficient binary array length representation TODO: return binwriter

Encodes and attempts to write the most efficient binary representation

Encodes and attempts to write the most efficient binary array length representation TODO: return str writer

Encodes and attempts to write the most efficient binary representation

Encodes and attempts to write the most efficient binary representation

Encodes and attempts to write the most efficient ext metadata representation

Panics

Panics if ty is negative, because it is reserved for future MessagePack extension including 2-byte type information.

Encodes and attempts to write a dynamic rmpv::Value

Panics

Panics if array or map length exceeds 2^32-1

Encodes and attempts to write a dynamic rmpv::ValueRef

Panics

Panics if array or map length exceeds 2^32-1