Struct rmp_futures::encode::ArrayFuture
source · [−]pub struct ArrayFuture<W> { /* private fields */ }Implementations
sourceimpl<W: AsyncWrite + Unpin> ArrayFuture<W>
impl<W: AsyncWrite + Unpin> ArrayFuture<W>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
sourcepub fn end(self) -> W
pub fn end(self) -> W
Return the underlying writer from this ArrayFuture that has already
written all elements (len == 0).
#Panics
Panics if self.is_empty() is false. next() must have been called as
many times as the array length originally written before calling this to
destroy the array wrapper.
sourcepub fn next(self) -> MsgPackWriter<Self>
pub fn next(self) -> MsgPackWriter<Self>
Return a MsgPackWriter for the next array element
Use for encoding a fixed amount of nesting of arrays/maps that can be
modeled with straight-line code. For recursion or looping where the depth
is not known at compile time, see next_dyn().
#Panics
Panics if self.is_empty() is true. next() must be called no more times
than the array length originally written.
sourcepub fn next_dyn(
&mut self
) -> MsgPackWriter<&mut (dyn AsyncWrite + Send + Unpin)>where
W: Send,
pub fn next_dyn(
&mut self
) -> MsgPackWriter<&mut (dyn AsyncWrite + Send + Unpin)>where
W: Send,
Return a MsgPackWriter for the next array element
Borrows from the ArrayFuture and the returned MsgPackWriter is based on
a trait object. This is useful for recursion. It is not possible to
manipulate this ArrayFuture while the MsgPackWriter exists, but the
user must be careful to write to it before dropping it, or the output
will be malformed.
#Panics
Panics if self.is_empty() is true. next() must be called no more times
than the array length originally written.
sourcepub fn last(self) -> MsgPackWriter<W>
pub fn last(self) -> MsgPackWriter<W>
If there is one element left, return a MsgPackWriter for the last array
element.
This will yield the underlying writer when the element is written. This
avoids have to also call end() after writing this element.
#Panics
Panics if self.len() != 1. next() must have been called as many times
as the array length originally written - 1 before calling this to destroy
the array wrapper.
pub async fn write_value(self, a: &[Value]) -> IoResult<W>where
W: Send,
pub async fn write_value_ref(self, a: &[ValueRef<'_>]) -> IoResult<W>where
W: Send,